AlekSIS (School Information System) — App Dashboard Feeds (Include feeds from external resources as widgets on dashboard)
=========================================================================================================================

AlekSIS
-------

This is an application for use with the `AlekSIS`_ platform.

Features
--------

* Add RSS widgets to dashboard
* Add iCal widgets to dashboard

Licence
-------

::

  Copyright © 2020 Dominik George <dominik.george@teckids.org>
  Copyright © 2020 Julian Leucker <leuckerj@gmail.com>

  Licenced under the EUPL, version 1.2 or later

Please see the LICENCE.rst file accompanying this distribution for the
full licence text or on the `European Union Public Licence`_ website
https://joinup.ec.europa.eu/collection/eupl/guidelines-users-and-developers
(including all other official language versions).

.. _AlekSIS: https://aleksis.org/
.. _European Union Public Licence: https://eupl.eu/
